.. currentmodule:: sardana.tango.pool.OneDExpChannel

:mod:`~sardana.tango.pool.OneDExpChannel`
===========================================

.. automodule:: sardana.tango.pool.OneDExpChannel

.. rubric:: Classes

.. hlist::
    :columns: 3

    * :class:`OneDExpChannel`
    * :class:`OneDExpChannelClass`

OneDExpChannel
------------------

.. inheritance-diagram:: OneDExpChannel
    :parts: 1
    
.. autoclass:: OneDExpChannel
    :show-inheritance:
    :members:
    :undoc-members:

OneDExpChannelClass
----------------------

.. inheritance-diagram:: OneDExpChannelClass
    :parts: 1
    
.. autoclass:: OneDExpChannelClass
    :show-inheritance:
    :members:
    :undoc-members:

